@@ -337,6 +337,8 @@
 
 - (BOOL)trackManualMove
 {
+  GdkWindow *window = [[self contentView] gdkWindow];
+  GdkWindowImplQuartz *impl = GDK_WINDOW_IMPL_QUARTZ (window->impl);
   NSPoint currentLocation;
   NSPoint newOrigin;
   NSRect screenFrame = [[NSScreen mainScreen] visibleFrame];
@@ -350,17 +352,21 @@
   newOrigin.y = currentLocation.y - initialMoveLocation.y;
 
   /* Clamp vertical position to below the menu bar. */
-  if (newOrigin.y + windowFrame.size.height > screenFrame.origin.y + screenFrame.size.height)
-    newOrigin.y = screenFrame.origin.y + screenFrame.size.height - windowFrame.size.height;
+  if (newOrigin.y + windowFrame.size.height - impl->shadow_top > screenFrame.origin.y + screenFrame.size.height)
+    newOrigin.y = screenFrame.origin.y + screenFrame.size.height - windowFrame.size.height + impl->shadow_top;
 
   [self setFrameOrigin:newOrigin];
 
   return YES;
 }
 
--(BOOL)isInManualResize
+/* Used by gdkevents-quartz.c to decide if our sendEvent() handler above
+ * will see the event or if it will be subjected to standard processing
+ * by GDK.
+*/
+-(BOOL)isInManualResizeOrMove
 {
-  return inManualResize;
+  return inManualResize || inManualMove;
 }
 
 -(void)beginManualMove
@@ -648,4 +654,19 @@ update_context_from_dragging_info (id <NSDraggingInfo> sender)
   _gdk_quartz_drag_source_context = NULL;
 }
 
+- (void)setStyleMask:(NSUInteger)styleMask
+{
+  gboolean was_fullscreen;
+  gboolean is_fullscreen;
+
+  was_fullscreen = (([self styleMask] & NSFullScreenWindowMask) != 0);
+
+  [super setStyleMask:styleMask];
+
+  is_fullscreen = (([self styleMask] & NSFullScreenWindowMask) != 0);
+
+  if (was_fullscreen != is_fullscreen)
+    _gdk_quartz_window_update_fullscreen_state ([[self contentView] gdkWindow]);
+}
+
 @end
