@@ -109,7 +109,7 @@ get_secret_cb (GObject      *source_object,
                      *key = NULL,
                      *value = NULL;
   GVariantIter       *iter = NULL;
-  guint               i, required_len;
+  guint               i;
   gint                pw_field = -1;
 
   task = user_data;
@@ -200,9 +200,10 @@ get_secret_cb (GObject      *source_object,
 
       g_variant_unref (secret);
 
-      if (ba_passwd == NULL)
+      if (ba_passwd == NULL || strlen (ba_passwd) > len + 1)
         {
-          GTK_NOTE (PRINTING, g_print ("Invalid / no secret found.\n"));
+          /* No secret or the secret is not a zero terminated value */
+          GTK_NOTE (PRINTING, g_print ("Invalid secret.\n"));
           g_variant_unref (s_value);
           goto fail;
         }
@@ -228,8 +229,7 @@ get_secret_cb (GObject      *source_object,
 fail:
   /* Error out */
   GTK_NOTE (PRINTING, g_print ("Failed to lookup secret.\n"));
-  required_len = g_strv_length (task_data->auth_info_required);
-  for (i = 0; i < required_len; i++)
+  for (i = 0; i < g_strv_length (task_data->auth_info_required); i++)
     {
       /* Not all fields of auth_info are neccessarily written so we can not
          use strfreev here */
@@ -531,13 +531,13 @@ unlock_read_alias_cb (GObject      *source_object,
                       GAsyncResult *res,
                       gpointer      user_data)
 {
-  GTask *task;
+  GTask              *task;
   SecretsServiceData *task_data;
-  GError *error = NULL;
-  GVariant *output, *subresult;
-  gsize path_len = 0;
-  const gchar *collection_path;
-  const gchar *to_unlock[2];
+  GError             *error = NULL;
+  GVariant           *output,
+                     *subresult;
+  gsize               path_len = 0;
+  const gchar        *collection_path;
 
   task = user_data;
   task_data = g_task_get_task_data (task);
@@ -562,8 +562,11 @@ unlock_read_alias_cb (GObject      *source_object,
     }
 
   collection_path = g_variant_get_string (subresult, &path_len);
-  to_unlock[0] = collection_path;
-  to_unlock[1] = NULL;
+
+  const gchar * const to_unlock[] =
+  {
+    collection_path, NULL
+  };
 
   task_data->collection_path = g_strdup (collection_path);
 
